<?php
namespace Teknisa\CDP\Modules\Producao\Controllers;

use Teknisa\CDP\Modules\Producao\Services\Cdp01100TarefaService;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\CDP\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use \Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\Environment;

class Cdp01100TarefaController extends TeknisaCrud {

    protected $dataSourceName = "tarefa_inspecao";
    protected $dataSourceNameToSave = "inspecao";
    protected $environment;
    protected $entityManager;
    protected $newCode;
    protected $Cdp01100TarefaService;

    public function __construct($crudService, $parameterBag, $environment, $entityManager, $newCode, Cdp01100TarefaService $Cdp01100TarefaService) {
        parent::__construct($crudService, $parameterBag);
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->newCode = $newCode;
        $this->Cdp01100TarefaService = $Cdp01100TarefaService;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $filterCriteria = $request->getFilterCriteria();
        $conditions     = $filterCriteria->getConditions();

        if(count($conditions) == 0) {
            $filterCriteria->addCondition("CDARVINSPECANTE", "=", null);
        }
        
        parent::find($request, $response);
        
        $dataSets = $response->getDataSets();
        if (count($dataSets) > 0) {
            $rows = $dataSets[0]->getRows();
            $rows = array_map(function($row) {
                $row['_hasChild'] = $row['HASCHILD'] === 'true' ? true : false;
                unset($row['HASCHILD']);
                return $row;
            }, $rows);
    
        $response->setDataSets(array(new DataSet('tarefa_inspecao', $rows)));
        }
    }
    
    public function save(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try {  
            if($row['__is_new']){
                $verificaPai = $this->Cdp01100TarefaService->verificaPai($row);
                $row['CDINSPECAO'] = $this->newCode->getCodeByTableName('CDINSPECAO', $this->environment->getNrOrgTrab());
            } else {
                $connection = $this->entityManager->getConnection();
                $connection->beginTransaction();
            }
            parent::save($request, $response);
            $this->entityManager->commit();
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function delete(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try {
            
            $verificaDelete = $this->Cdp01100TarefaService->verificaDelete($row);
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function updateTarefaDesc(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            $this->Cdp01100TarefaService->updateTarefaDesc($row);
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}