<?php
/**
 * Suprimentos\Repositories
 *
 * @category Php
 * @package  Suprimentos\Repositories
 * @author   danilovaz <danilo.vaz@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Suprimentos\Repositories;

/**
 * Class Movopsol
 *
 * @category Php
 * @package  Suprimentos\Repositories
 * @author   danilovaz <danilo.vaz@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class Movopsol extends \Doctrine\ORM\EntityRepository
{
    /**
     * Desabilita a trigger GRAVA_MOVOPSOL utilizada pela aplica��o em Delphi
     * para utilizar a aplica��o no Browser
     *
     * @return null
     */
    public static function disableTrigger()
    {
        $conn = \Setforms2\Runtime\Connection::getInstance();
        $existe = self::pesquisaTriggerGravamovopsol($conn);

        if ($existe) {
            $query = "ALTER TRIGGER GRAVA_MOVOPSOL DISABLE";
            $conn->execute($query);
        }

    }

    /**
     * Habilita a trigger GRAVA_MOVOPSOL utilizada pela aplica??o em Delphi
     * ap?s ser desabilitada e utilizada aplica??o no Browser
     *
     * @return null
     */
    public static function enableTrigger()
    {
        $conn = \Setforms2\Runtime\Connection::getInstance();
        $existe = self::pesquisaTriggerGravamovopsol($conn);

        if ($existe) {
            $query = "ALTER TRIGGER GRAVA_MOVOPSOL ENABLE";
            $conn->execute($query);
        }
    }

    /**
     * Verifica se a trigger GRAVA_MOVOPSOL existe para aquele usuário da base de dados.
     *
     * @param \Setforms2\Runtime\Connection $conn Conn
     *
     * @return bool
     */
    public static function pesquisaTriggerGravamovopsol($conn)
    {
        $trigger = "SELECT
                      TRIGGER_NAME
                    FROM ALL_TRIGGERS
                    WHERE TRIGGER_NAME = 'GRAVA_MOVOPSOL'
                      AND OWNER IN (SELECT USERNAME FROM USER_USERS)
                   ";

        $result = $conn->fetchAll($trigger);

        if (empty($result)) {
            return false;
        } else {
            return true;
        }
    }

//    /**
//     * Insere na tabela MOVOPSOL uma nova justificativa
//     *
//     * @param String $cdfilsol    Cdfilsol
//     * @param String $cdfillanca  Cdfillanca
//     * @param String $nrsolicita  Nrsolicita
//     * @param String $cdproduto   Cdproduto
//     * @param String $dtentroper  Dtentroper
//     * @param String $dtopersol   Dtopersol
//     * @param String $cdoperador  Cdoperador
//     * @param String $dsjustoper  Dsjustoper
//     * @param String $qtantoper   Qtantoper
//     * @param String $qtdepoper   Qtdepoper
//     * @param String $idaltplalog Idaltplalog
//     * @param String $idoperamovs Idoperamovs
//     * @param String $nrorg       Nrorg
//     *
//     * @return null
//     */
//    public function insereJustAlteracao($cdfilsol, $cdfillanca, $nrsolicita, $cdproduto, $dtentroper, $dtopersol, $cdoperador, $dsjustoper, $qtantoper, $qtdepoper, $idaltplalog, $idoperamovs, $nrorg)
//    {
//        $query = "INSERT
//  					INTO MOVOPSOL(CDFILSOLMOV,CDFILLANMOV,NRSOLIMOV,CDPRODUTO,DTENTROPER,DTOPERSOL,CDOPERADOR,DSJUSTOPER,QTANTOPER,QTDEPOPER,IDALTPLALOG,IDOPERAMOVS,NRORG)
//				  VALUES
//			  		(:P_CDFILSOL, :P_CDFILLANCA, :P_NRSOLICITA, :P_CDPRODUTO, :P_DTENTROPER, :P_DTOPERSOL, :P_CDOPERADOR, :P_DSJUSTOPER, :P_QTANTOPER, :P_QTDEPOPER, :P_IDALTPLALOG, :P_IDOPERAMOVS, :P_NRORG)
//			  	 ";
//
//        $params = array(
//            'P_CDFILSOL' => $cdfilsol, 'P_CDFILLANCA' => $cdfillanca, 'P_NRSOLICITA' => $nrsolicita,
//            'P_CDPRODUTO' => $cdproduto, 'P_DTENTROPER' => $dtentroper, 'P_DTOPERSOL' => $dtopersol,
//            'P_CDOPERADOR' => $cdoperador, 'P_DSJUSTOPER' => $dsjustoper, 'P_QTANTOPER' => $qtantoper,
//            'P_QTDEPOPER' => $qtdepoper, 'P_IDALTPLALOG' => $idaltplalog, 'P_IDOPERAMOVS' => $idoperamovs, 'P_NRORG' => $nrorg
//        );
//
//        return $this->_em->getConnection()->executeQuery($query, $params);
//    }


    /**
     * Insere na tabela MOVOPSOL uma nova justificativa
     *
     * @param String $cdfilsol    Cdfilsol
     * @param String $cdfillanca  Cdfillanca
     * @param String $nrsolicita  Nrsolicita
     * @param String $cdproduto   Cdproduto
     * @param String $dtentroper  Dtentroper
     * @param String $dtopersol   Dtopersol
     * @param String $cdoperador  Cdoperador
     * @param String $dsjustoper  Dsjustoper
     * @param String $qtantoper   Qtantoper
     * @param String $qtdepoper   Qtdepoper
     * @param String $idaltplalog Idaltplalog
     * @param String $idoperamovs Idoperamovs
     * @param String $nrorg       Nrorg
     *
     * @return null
     */
    public static function insereJustAlteracao(
        $cdfilsol, $cdfillanca, $nrsolicita, $cdproduto, $dtentroper,
        $dtopersol, $cdoperador, $dsjustoper, $qtantoper, $qtdepoper,
        $idaltplalog, $idoperamovs, $nrorg
    )
    {
        $query
            = "INSERT
  					INTO MOVOPSOL(CDFILSOLMOV,CDFILLANMOV,NRSOLIMOV,CDPRODUTO,DTENTROPER,DTOPERSOL,CDOPERADOR,DSJUSTOPER,QTANTOPER,QTDEPOPER,IDALTPLALOG,IDOPERAMOVS,NRORG)
				  VALUES
			  		(:P_CDFILSOL, :P_CDFILLANCA, :P_NRSOLICITA, :P_CDPRODUTO, :P_DTENTROPER, :P_DTOPERSOL, :P_CDOPERADOR, :P_DSJUSTOPER, :P_QTANTOPER, :P_QTDEPOPER, :P_IDALTPLALOG, :P_IDOPERAMOVS, :P_NRORG)
			  	 ";
        $params = array(
            'P_CDFILSOL' => $cdfilsol, 'P_CDFILLANCA' => $cdfillanca,
            'P_NRSOLICITA' => $nrsolicita, 'P_CDPRODUTO' => $cdproduto,
            'P_DTENTROPER' => $dtentroper, 'P_DTOPERSOL' => $dtopersol,
            'P_CDOPERADOR' => $cdoperador, 'P_DSJUSTOPER' => $dsjustoper,
            'P_QTANTOPER' => $qtantoper,
            'P_QTDEPOPER' => $qtdepoper, 'P_IDALTPLALOG' => $idaltplalog,
            'P_IDOPERAMOVS' => $idoperamovs, 'P_NRORG' => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $params);
        } catch (\Exception $e) {
            throw $e;
        }

    }

    /**
     * Atualiza a tabela MOVOPSOL
     *
     * @param String $cdfilsol   Cdfilsol
     * @param String $cdfillanca Cdfillanca
     * @param String $nrsolicita Nrsolicita
     * @param String $cdproduto  Cdproduto
     * @param String $dtentroper Dtentroper
     * @param String $dtopersol  Dtopersol
     * @param String $cdoperador Cdoperador
     * @param String $dsjustoper Dsjustoper
     * @param String $qtantoper  Qtantoper
     * @param String $qtdepoper  Qtdepoper
     * @param String $nrorg      Nrorg
     *
     * @return null
     */
    public static function atualizaJustAlteracao($cdfilsol, $cdfillanca, $nrsolicita, $cdproduto, $dtentroper, $dtopersol, $cdoperador, $dsjustoper, $qtantoper, $qtdepoper, $nrorg)
    {
        $query = "UPDATE MOVOPSOL
					SET DSJUSTOPER = '$dsjustoper'
				  WHERE CDFILSOLMOV = '$cdfilsol'
					AND CDFILLANMOV = '$cdfillanca'
					AND NRSOLIMOV = '$nrsolicita'
					AND CDPRODUTO = '$cdproduto'
					AND DTOPERSOL = '$dtopersol'
					AND CDOPERADOR = '$cdoperador'
					AND DTENTROPER = '$dtentroper'
					AND QTANTOPER = '$qtantoper'
					AND QTDEPOPER = '$qtdepoper'
					AND NRORG = '$nrorg'
				";

        $conn = \Setforms2\Runtime\Connection::getInstance();
        $conn->execute($query);

    }


    /**
     * Verifica se a filial exige inserção de justificativa
     *
     * @param $cdfilial
     * @return String
     */
    public static function verificaFilialInsereJust($cdfilial)
    {
        $query = "SELECT PARASUPRI.IDEXIGAPRGERCMP
                  FROM PARCMPSUP,
                    PARASUPRI,
                    FILIAL
                  WHERE PARCMPSUP.CDFILIAL = FILIAL.CDFILIAL
                    AND PARASUPRI.CDFILIAL   = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                    AND FILIAL.CDFILIAL      = :P_CDFILIAL
                  ";

        $param = array('P_CDFILIAL' => $cdfilial);
        try {
//            return $this->_em->getConnection()->fetchAll($query, $param);
            $conn = \Setforms2\Runtime\Connection::getInstance();
            return $conn->fetchAll($query, $param);
        } catch (\Exception $e) {
            throw $e;
        }
    }


    /**
     * Verifica se existe justificativa de alteracao para algum item da filial
     *
     * @static
     *
     * @param $nrorg
     * @param $cdfillanmov
     * @param $cdfilsolmov
     * @param $nrsolimov
     *
     * @return array
     */
    public static function verificaJust($nrorg, $cdfilsoli, $cdfillan, $nrsolicmp)
    {
        $query = "SELECT *
                  FROM MOVOPSOL
                  WHERE NRORG = :P_NRORG
                  AND CDFILSOLMOV = :P_CDFILSOLMOV
                  AND CDFILLANMOV   = :P_CDFILLANMOV
                  AND NRSOLIMOV     = :P_NRSOLIMOV
                  ";

        $param = array('P_NRORG' => $nrorg, 'P_CDFILSOLMOV' => $cdfilsoli, 'P_CDFILLANMOV' => $cdfillan, 'P_NRSOLIMOV' => $nrsolicmp);
        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            return $conn->fetchAll($query, $param);
        } catch (\Exception $e) {
            throw $e;
        }
    }

/**
     * Exclui justificativa de alteracao dos itens da filial
     *
     * @static
     *
     * @param $nrorg
     * @param $cdfillanmov
     * @param $cdfilsolmov
     * @param $nrsolimov
     *
     * @return null
     */
    public static function excluiJust($nrorg, $cdfilsoli, $cdfillan, $nrsolicmp)
    {
        $query = "DELETE
                  FROM MOVOPSOL
                  WHERE NRORG = :P_NRORG
                  AND CDFILSOLMOV = :P_CDFILSOLMOV
                  AND CDFILLANMOV   = :P_CDFILLANMOV
                  AND NRSOLIMOV     = :P_NRSOLIMOV
                  ";

        $param = array('P_NRORG' => $nrorg, 'P_CDFILSOLMOV' => $cdfilsoli, 'P_CDFILLANMOV' => $cdfillan, 'P_NRSOLIMOV' => $nrsolicmp);
        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            return $conn->execute($query, $param);
        } catch (\Exception $e) {
            throw $e;
        }
    }


}